dSFMT-jump: Main Page

dSFMT-jump 0.1

- Main Page
- Namespaces
- Data Structures
- Files

dSFMT-jump Documentation

This is SIMD oriented Fast Mersenne Twister pseudorandom number generator(dSFMT) with jump function. This Project provides jump function of dSFMT.

There are two steps for jumpping.

1. Calculate jump polynomial using magic polynomial.
   - calc-jump executable file calculates a jump polynomial.
   - calc-jump is written in C++ language and needs NTL for compile.
   - Additionally, users can call dsfmt::calc_jump(std::string& jump_str, NTL::ZZ& step, NTL::GF2X& characteristic) in SFMT-calc-jump.hpp from their programs.
   - jump steps used above is based on internal state, i.e, doubles are skipped 2 * jump steps.
2. Change internal state of dSFMT into jumpped state.
   - dSFMT_jump(dsfmt_t * dsfmt, const char * jump_str) changes internal state of dsfmt in user's programs.
   - See also:
       sample1.c sample2.c

Caution: The jump polynomial calculated using a magic polynomial is only available for jumpping dSFMT states which has MEXP correspond to the magic polynomial.

Author:
  Mutsuo Saito (Hiroshima University)
  Makoto Matsumoto (The University of Tokyo)

Date:
  2012-07-03

Copyright (C) 2012 Mutsuo Saito, Makoto Matsumoto, Hiroshima University and The University of Tokyo. All rights reserved.

The 3-clause BSD License is applied to this software.

    Copyright (c) 2007, 2008, 2009 Mutsuo Saito, Makoto Matsumoto
    and Hiroshima University.
    Copyright (c) 2011, 2012 Mutsuo Saito, Makoto Matsumoto, Hiroshima
    University and The University of Tokyo.
    All rights reserved.

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
    met:

        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above
          copyright notice, this list of conditions and the following
          disclaimer in the documentation and/or other materials provided
          with the distribution.
        * Neither the name of the Hiroshima University nor the names of
          its contributors may be used to endorse or promote products
          derived from this software without specific prior written
          permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
    OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.